@@ -11,7 +11,6 @@ from __future__ import annotations
 
 import datetime
 import enum
-import inspect
 import json
 import logging
 import operator
@@ -20,6 +19,7 @@ import sys
 import threading
 import time
 
+from types import FrameType, TracebackType
 from typing import (
     Any,
     Callable,
@@ -28,6 +28,7 @@ from typing import (
     NamedTuple,
     Sequence,
     TextIO,
+    cast,
 )
 
 from ._frames import (
@@ -35,27 +36,33 @@ from ._frames import (
     _format_exception,
     _format_stack,
 )
-from ._log_levels import _NAME_TO_LEVEL, add_log_level
+from ._log_levels import NAME_TO_LEVEL, add_log_level
 from ._utils import get_processname
 from .tracebacks import ExceptionDictTransformer
-from .typing import EventDict, ExceptionTransformer, ExcInfo, WrappedLogger
+from .typing import (
+    EventDict,
+    ExceptionTransformer,
+    ExcInfo,
+    WrappedLogger,
+)
 
 
 __all__ = [
-    "_NAME_TO_LEVEL",  # some people rely on it being here
-    "add_log_level",
+    "NAME_TO_LEVEL",  # some people rely on it being here
     "CallsiteParameter",
     "CallsiteParameterAdder",
-    "dict_tracebacks",
     "EventRenamer",
     "ExceptionPrettyPrinter",
-    "format_exc_info",
     "JSONRenderer",
     "KeyValueRenderer",
+    "LogfmtRenderer",
     "StackInfoRenderer",
     "TimeStamper",
     "UnicodeDecoder",
     "UnicodeEncoder",
+    "add_log_level",
+    "dict_tracebacks",
+    "format_exc_info",
 ]
 
 
@@ -63,16 +70,20 @@ class KeyValueRenderer:
     """
     Render ``event_dict`` as a list of ``Key=repr(Value)`` pairs.
 
-    :param sort_keys: Whether to sort keys when formatting.
-    :param key_order: List of keys that should be rendered in this exact
-        order.  Missing keys will be rendered as ``None``, extra keys depending
-        on *sort_keys* and the dict class.
-    :param drop_missing: When ``True``, extra keys in *key_order* will be
-        dropped rather than rendered as ``None``.
-    :param repr_native_str: When ``True``, :func:`repr()` is also applied
-        to native strings.
-        Setting this to ``False`` is useful if you want to have human-readable
-        non-ASCII output on Python 2.
+    Args:
+        sort_keys: Whether to sort keys when formatting.
+
+        key_order:
+            List of keys that should be rendered in this exact order.  Missing
+            keys will be rendered as ``None``, extra keys depending on
+            *sort_keys* and the dict class.
+
+        drop_missing:
+            When ``True``, extra keys in *key_order* will be dropped rather
+            than rendered as ``None``.
+
+        repr_native_str:
+            When ``True``, :func:`repr()` is also applied to native strings.
 
     .. versionadded:: 0.2.0 *key_order*
     .. versionadded:: 16.1.0 *drop_missing*
@@ -114,17 +125,25 @@ class LogfmtRenderer:
 
     .. _logfmt: https://brandur.org/logfmt
 
-    :param sort_keys: Whether to sort keys when formatting.
-    :param key_order: List of keys that should be rendered in this exact
-        order. Missing keys are rendered with empty values, extra keys
-        depending on *sort_keys* and the dict class.
-    :param drop_missing: When ``True``, extra keys in *key_order* will be
-        dropped rather than rendered with empty values.
-    :param bool_as_flag: When ``True``, render ``{"flag": True}`` as
-        ``flag``, instead of ``flag=true``. ``{"flag": False}`` is
-        always rendered as ``flag=false``.
+    Args:
+        sort_keys: Whether to sort keys when formatting.
 
-    :raises ValueError: If a key contains non printable or space characters.
+        key_order:
+            List of keys that should be rendered in this exact order. Missing
+            keys are rendered with empty values, extra keys depending on
+            *sort_keys* and the dict class.
+
+        drop_missing:
+            When ``True``, extra keys in *key_order* will be dropped rather
+            than rendered with empty values.
+
+        bool_as_flag:
+            When ``True``, render ``{"flag": True}`` as ``flag``, instead of
+            ``flag=true``. ``{"flag": False}`` is always rendered as
+            ``flag=false``.
+
+    Raises:
+        ValueError: If a key contains non-printable or whitespace characters.
 
     .. versionadded:: 21.5.0
     """
@@ -145,7 +164,8 @@ class LogfmtRenderer:
         elements: list[str] = []
         for key, value in self._ordered_items(event_dict):
             if any(c <= " " for c in key):
-                raise ValueError(f'Invalid key: "{key}"')
+                msg = f'Invalid key: "{key}"'
+                raise ValueError(msg)
 
             if value is None:
                 elements.append(f"{key}=")
@@ -157,9 +177,16 @@ class LogfmtRenderer:
                     continue
                 value = "true" if value else "false"
 
-            value = f"{value}".replace('"', '\\"')
+            value = str(value)
+            backslashes_need_escaping = (
+                " " in value or "=" in value or '"' in value
+            )
+            if backslashes_need_escaping and "\\" in value:
+                value = value.replace("\\", "\\\\")
 
-            if " " in value or "=" in value:
+            value = value.replace('"', '\\"').replace("\n", "\\n")
+
+            if backslashes_need_escaping:
                 value = f'"{value}"'
 
             elements.append(f"{key}={value}")
@@ -171,7 +198,7 @@ def _items_sorter(
     sort_keys: bool,
     key_order: Sequence[str] | None,
     drop_missing: bool,
-) -> Callable[[EventDict], list[tuple[str, Any]]]:
+) -> Callable[[EventDict], list[tuple[str, object]]]:
     """
     Return a function to sort items from an ``event_dict``.
 
@@ -182,7 +209,7 @@ def _items_sorter(
 
         def ordered_items(event_dict: EventDict) -> list[tuple[str, Any]]:
             items = []
-            for key in key_order:  # type: ignore[union-attr]
+            for key in key_order:
                 value = event_dict.pop(key, None)
                 if value is not None or not drop_missing:
                     items.append((key, value))
@@ -195,7 +222,7 @@ def _items_sorter(
 
         def ordered_items(event_dict: EventDict) -> list[tuple[str, Any]]:
             items = []
-            for key in key_order:  # type: ignore[union-attr]
+            for key in key_order:
                 value = event_dict.pop(key, None)
                 if value is not None or not drop_missing:
                     items.append((key, value))
@@ -221,14 +248,15 @@ class UnicodeEncoder:
     """
     Encode unicode values in ``event_dict``.
 
-    :param encoding: Encoding to encode to (default: ``"utf-8"``).
-    :param errors: How to cope with encoding errors (default
-        ``"backslashreplace"``).
+    Args:
+        encoding: Encoding to encode to (default: ``"utf-8"``).
 
-    Useful if you're running Python 2 as otherwise ``u"abc"`` will be rendered
-    as ``'u"abc"'``.
+        errors:
+            How to cope with encoding errors (default ``"backslashreplace"``).
 
     Just put it in the processor chain before the renderer.
+
+    .. note:: Not very useful in a Python 3-only world.
     """
 
     _encoding: str
@@ -254,12 +282,12 @@ class UnicodeDecoder:
     """
     Decode byte string values in ``event_dict``.
 
-    :param encoding: Encoding to decode from (default: ``"utf-8"``).
-    :param errors: How to cope with encoding errors (default:
-        ``"replace"``).
+    Args:
+        encoding: Encoding to decode from (default: ``"utf-8"``).
 
-    Useful if you're running Python 3 as otherwise ``b"abc"`` will be rendered
-    as ``'b"abc"'``.
+        errors: How to cope with encoding errors (default: ``"replace"``).
+
+    Useful to prevent ``b"abc"`` being rendered as as ``'b"abc"'``.
 
     Just put it in the processor chain before the renderer.
 
@@ -289,24 +317,22 @@ class JSONRenderer:
     """
     Render the ``event_dict`` using ``serializer(event_dict, **dumps_kw)``.
 
-    :param dumps_kw: Are passed unmodified to *serializer*.  If *default*
-        is passed, it will disable support for ``__structlog__``-based
-        serialization.
-    :param serializer: A :func:`json.dumps`-compatible callable that
-        will be used to format the string.  This can be used to use alternative
-        JSON encoders like `orjson <https://pypi.org/project/orjson/>`__ or
-        `RapidJSON <https://pypi.org/project/python-rapidjson/>`_  (default:
-        :func:`json.dumps`).
+    Args:
+        dumps_kw:
+            Are passed unmodified to *serializer*.  If *default* is passed, it
+            will disable support for ``__structlog__``-based serialization.
 
-    .. versionadded:: 0.2.0
-        Support for ``__structlog__`` serialization method.
+        serializer:
+            A :func:`json.dumps`-compatible callable that will be used to
+            format the string.  This can be used to use alternative JSON
+            encoders (default: :func:`json.dumps`).
 
-    .. versionadded:: 15.4.0
-        *serializer* parameter.
+            .. seealso:: :doc:`performance` for examples.
 
+    .. versionadded:: 0.2.0 Support for ``__structlog__`` serialization method.
+    .. versionadded:: 15.4.0 *serializer* parameter.
     .. versionadded:: 18.2.0
        Serializer's *default* parameter can be overwritten now.
-
     """
 
     def __init__(
@@ -349,12 +375,12 @@ class ExceptionRenderer:
     by *exception_formatter*.
 
     The contents of the ``exception`` field depends on the return value of the
-    :class:`.ExceptionTransformer` that is used:
+    *exception_formatter* that is passed:
 
     - The default produces a formatted string via Python's built-in traceback
-      formatting.
-    - The :class:`~structlog.tracebacks.ExceptionDictTransformer` a list of
-      stack dicts that can be serialized to JSON.
+      formatting (this is :obj:`.format_exc_info`).
+    - If you pass a :class:`~structlog.tracebacks.ExceptionDictTransformer`, it
+      becomes a list of stack dicts that can be serialized to JSON.
 
     If *event_dict* contains the key ``exc_info``, there are three possible
     behaviors:
@@ -364,13 +390,19 @@ class ExceptionRenderer:
     3. If the value true but no tuple, obtain exc_info ourselves and render
        that.
 
-    If there is no ``exc_info`` key, the *event_dict* is not touched.
-    This behavior is analogue to the one of the stdlib's logging.
+    If there is no ``exc_info`` key, the *event_dict* is not touched. This
+    behavior is analog to the one of the stdlib's logging.
 
-    :param exception_formatter: A callable that is used to format the exception
-        from the ``exc_info`` field.
+    Args:
+        exception_formatter:
+            A callable that is used to format the exception from the
+            ``exc_info`` field into the ``exception`` field.
 
-    .. versionadded:: 22.1
+    .. seealso::
+        :doc:`exceptions` for a broader explanation of *structlog*'s exception
+        features.
+
+    .. versionadded:: 22.1.0
     """
 
     def __init__(
@@ -382,19 +414,17 @@ class ExceptionRenderer:
     def __call__(
         self, logger: WrappedLogger, name: str, event_dict: EventDict
     ) -> EventDict:
-        exc_info = event_dict.pop("exc_info", None)
+        exc_info = _figure_out_exc_info(event_dict.pop("exc_info", None))
         if exc_info:
-            event_dict["exception"] = self.format_exception(
-                _figure_out_exc_info(exc_info)
-            )
+            event_dict["exception"] = self.format_exception(exc_info)
 
         return event_dict
 
 
 format_exc_info = ExceptionRenderer()
 """
-Replace an ``exc_info`` field with an ``exception`` string field using
-Python's built-in traceback formatting.
+Replace an ``exc_info`` field with an ``exception`` string field using Python's
+built-in traceback formatting.
 
 If *event_dict* contains the key ``exc_info``, there are three possible
 behaviors:
@@ -404,8 +434,12 @@ behaviors:
 3. If the value is true but no tuple, obtain exc_info ourselves and render
    that.
 
-If there is no ``exc_info`` key, the *event_dict* is not touched.
-This behavior is analogue to the one of the stdlib's logging.
+If there is no ``exc_info`` key, the *event_dict* is not touched. This behavior
+is analog to the one of the stdlib's logging.
+
+.. seealso::
+    :doc:`exceptions` for a broader explanation of *structlog*'s exception
+    features.
 """
 
 dict_tracebacks = ExceptionRenderer(ExceptionDictTransformer())
@@ -418,7 +452,11 @@ It is a shortcut for :class:`ExceptionRenderer` with a
 
 The treatment of the ``exc_info`` key is identical to `format_exc_info`.
 
-.. versionadded:: 22.1
+.. versionadded:: 22.1.0
+
+.. seealso::
+    :doc:`exceptions` for a broader explanation of *structlog*'s exception
+    features.
 """
 
 
@@ -426,16 +464,20 @@ class TimeStamper:
     """
     Add a timestamp to ``event_dict``.
 
-    :param fmt: strftime format string, or ``"iso"`` for `ISO 8601
-        <https://en.wikipedia.org/wiki/ISO_8601>`_, or `None` for a `UNIX
-        timestamp <https://en.wikipedia.org/wiki/Unix_time>`_.
-    :param utc: Whether timestamp should be in UTC or local time.
-    :param key: Target key in *event_dict* for added timestamps.
+    Args:
+        fmt:
+            strftime format string, or ``"iso"`` for `ISO 8601
+            <https://en.wikipedia.org/wiki/ISO_8601>`_, or `None` for a `UNIX
+            timestamp <https://en.wikipedia.org/wiki/Unix_time>`_.
 
-    .. versionchanged:: 19.2 Can be pickled now.
+        utc: Whether timestamp should be in UTC or local time.
+
+        key: Target key in *event_dict* for added timestamps.
+
+    .. versionchanged:: 19.2.0 Can be pickled now.
     """
 
-    __slots__ = ("_stamper", "fmt", "utc", "key")
+    __slots__ = ("_stamper", "fmt", "key", "utc")
 
     def __init__(
         self,
@@ -470,19 +512,22 @@ def _make_stamper(
     Create a stamper function.
     """
     if fmt is None and not utc:
-        raise ValueError("UNIX timestamps are always UTC.")
+        msg = "UNIX timestamps are always UTC."
+        raise ValueError(msg)
 
     now: Callable[[], datetime.datetime]
 
     if utc:
 
         def now() -> datetime.datetime:
-            return datetime.datetime.utcnow()
+            return datetime.datetime.now(tz=datetime.timezone.utc)
 
     else:
 
         def now() -> datetime.datetime:
-            return datetime.datetime.now()
+            # We don't need the TZ for our own formatting. We add it only for
+            # user-defined formats later.
+            return datetime.datetime.now()  # noqa: DTZ005
 
     if fmt is None:
 
@@ -500,7 +545,7 @@ def _make_stamper(
             return event_dict
 
         def stamper_iso_utc(event_dict: EventDict) -> EventDict:
-            event_dict[key] = now().isoformat() + "Z"
+            event_dict[key] = now().isoformat().replace("+00:00", "Z")
             return event_dict
 
         if utc:
@@ -509,41 +554,82 @@ def _make_stamper(
         return stamper_iso_local
 
     def stamper_fmt(event_dict: EventDict) -> EventDict:
-        event_dict[key] = now().strftime(fmt)  # type: ignore[arg-type]
+        event_dict[key] = now().astimezone().strftime(fmt)
 
         return event_dict
 
     return stamper_fmt
 
 
-def _figure_out_exc_info(v: Any) -> ExcInfo:
+class MaybeTimeStamper:
     """
-    Depending on the Python version will try to do the smartest thing possible
-    to transform *v* into an ``exc_info`` tuple.
+    A timestamper that only adds a timestamp if there is none.
+
+    This allows you to overwrite the ``timestamp`` key in the event dict for
+    example when the event is coming from another system.
+
+    It takes the same arguments as `TimeStamper`.
+
+    .. versionadded:: 23.2.0
+    """
+
+    __slots__ = ("stamper",)
+
+    def __init__(
+        self,
+        fmt: str | None = None,
+        utc: bool = True,
+        key: str = "timestamp",
+    ):
+        self.stamper = TimeStamper(fmt=fmt, utc=utc, key=key)
+
+    def __call__(
+        self, logger: WrappedLogger, name: str, event_dict: EventDict
+    ) -> EventDict:
+        if "timestamp" not in event_dict:
+            return self.stamper(logger, name, event_dict)
+
+        return event_dict
+
+
+def _figure_out_exc_info(v: Any) -> ExcInfo | None:
+    """
+    Try to convert *v* into an ``exc_info`` tuple.
+
+    Return ``None`` if *v* does not represent an exception or if there is no
+    current exception.
     """
     if isinstance(v, BaseException):
         return (v.__class__, v, v.__traceback__)
 
-    if isinstance(v, tuple):
-        return v  # type: ignore[return-value]
+    if isinstance(v, tuple) and len(v) == 3:
+        has_type = isinstance(v[0], type) and issubclass(v[0], BaseException)
+        has_exc = isinstance(v[1], BaseException)
+        has_tb = v[2] is None or isinstance(v[2], TracebackType)
+        if has_type and has_exc and has_tb:
+            return v
 
     if v:
-        return sys.exc_info()  # type: ignore[return-value]
+        result = sys.exc_info()
+        if result == (None, None, None):
+            return None
+        return cast(ExcInfo, result)
 
-    return v
+    return None
 
 
 class ExceptionPrettyPrinter:
     """
     Pretty print exceptions and remove them from the ``event_dict``.
 
-    :param file: Target file for output (default: ``sys.stdout``).
+    Args:
+        file: Target file for output (default: ``sys.stdout``).
 
     This processor is mostly for development and testing so you can read
     exceptions properly formatted.
 
-    It behaves like `format_exc_info` except it removes the exception
-    data from the event dictionary after printing it.
+    It behaves like `format_exc_info` except it removes the exception data from
+    the event dictionary after printing it.
 
     It's tolerant to having `format_exc_info` in front of itself in the
     processor chain but doesn't require it.  In other words, it handles both
@@ -588,19 +674,22 @@ class StackInfoRenderer:
     involving an exception and works analogously to the *stack_info* argument
     of the Python standard library logging.
 
-    :param additional_ignores: By default, stack frames coming from
-        *structlog* are ignored. With this argument you can add additional
-        names that are ignored, before the stack starts being rendered. They
-        are matched using ``startswith()``, so they don't have to match
-        exactly. The names are used to find the first relevant name, therefore
-        once a frame is found that doesn't start with *structlog* or one of
-        *additional_ignores*, **no filtering** is applied to subsequent frames.
+    Args:
+        additional_ignores:
+            By default, stack frames coming from *structlog* are ignored. With
+            this argument you can add additional names that are ignored, before
+            the stack starts being rendered. They are matched using
+            ``startswith()``, so they don't have to match exactly. The names
+            are used to find the first relevant name, therefore once a frame is
+            found that doesn't start with *structlog* or one of
+            *additional_ignores*, **no filtering** is applied to subsequent
+            frames.
 
     .. versionadded:: 0.4.0
     .. versionadded:: 22.1.0  *additional_ignores*
     """
 
-    __slots__ = ["_additional_ignores"]
+    __slots__ = ("_additional_ignores",)
 
     def __init__(self, additional_ignores: list[str] | None = None) -> None:
         self._additional_ignores = additional_ignores
@@ -650,6 +739,42 @@ class CallsiteParameter(enum.Enum):
     PROCESS_NAME = "process_name"
 
 
+def _get_callsite_pathname(module: str, frame: FrameType) -> Any:
+    return frame.f_code.co_filename
+
+
+def _get_callsite_filename(module: str, frame: FrameType) -> Any:
+    return os.path.basename(frame.f_code.co_filename)
+
+
+def _get_callsite_module(module: str, frame: FrameType) -> Any:
+    return os.path.splitext(os.path.basename(frame.f_code.co_filename))[0]
+
+
+def _get_callsite_func_name(module: str, frame: FrameType) -> Any:
+    return frame.f_code.co_name
+
+
+def _get_callsite_lineno(module: str, frame: FrameType) -> Any:
+    return frame.f_lineno
+
+
+def _get_callsite_thread(module: str, frame: FrameType) -> Any:
+    return threading.get_ident()
+
+
+def _get_callsite_thread_name(module: str, frame: FrameType) -> Any:
+    return threading.current_thread().name
+
+
+def _get_callsite_process(module: str, frame: FrameType) -> Any:
+    return os.getpid()
+
+
+def _get_callsite_process_name(module: str, frame: FrameType) -> Any:
+    return get_processname()
+
+
 class CallsiteParameterAdder:
     """
     Adds parameters of the callsite that an event dictionary originated from to
@@ -657,10 +782,6 @@ class CallsiteParameterAdder:
     dictionaries with information such as the function name, line number and
     filename that an event dictionary originated from.
 
-    .. warning::
-        This processor cannot detect the correct callsite for invocation of
-        async functions.
-
     If the event dictionary has an embedded `logging.LogRecord` object and did
     not originate from *structlog* then the callsite information will be
     determined from the `logging.LogRecord` object. For event dictionaries
@@ -672,15 +793,17 @@ class CallsiteParameterAdder:
     The keys used for callsite parameters in the event dictionary are the
     string values of `CallsiteParameter` enum members.
 
-    :param parameters:
-        A collection of `CallsiteParameter` values that should be added to the
-        event dictionary.
+    Args:
+        parameters:
+            A collection of `CallsiteParameter` values that should be added to
+            the event dictionary.
 
-    :param additional_ignores:
-        Additional names with which a stack frame's module name must not
-        start for it to be considered when determening the callsite.
+        additional_ignores:
+            Additional names with which a stack frame's module name must not
+            start for it to be considered when determening the callsite.
 
     .. note::
+
         When used with `structlog.stdlib.ProcessorFormatter` the most efficient
         configuration is to either use this processor in ``foreign_pre_chain``
         of `structlog.stdlib.ProcessorFormatter` and in ``processors`` of
@@ -693,35 +816,17 @@ class CallsiteParameterAdder:
     """
 
     _handlers: ClassVar[
-        dict[CallsiteParameter, Callable[[str, inspect.Traceback], Any]]
+        dict[CallsiteParameter, Callable[[str, FrameType], Any]]
     ] = {
-        CallsiteParameter.PATHNAME: (
-            lambda module, frame_info: frame_info.filename
-        ),
-        CallsiteParameter.FILENAME: (
-            lambda module, frame_info: os.path.basename(frame_info.filename)
-        ),
-        CallsiteParameter.MODULE: (
-            lambda module, frame_info: os.path.splitext(
-                os.path.basename(frame_info.filename)
-            )[0]
-        ),
-        CallsiteParameter.FUNC_NAME: (
-            lambda module, frame_info: frame_info.function
-        ),
-        CallsiteParameter.LINENO: (
-            lambda module, frame_info: frame_info.lineno
-        ),
-        CallsiteParameter.THREAD: (
-            lambda module, frame_info: threading.get_ident()
-        ),
-        CallsiteParameter.THREAD_NAME: (
-            lambda module, frame_info: threading.current_thread().name
-        ),
-        CallsiteParameter.PROCESS: (lambda module, frame_info: os.getpid()),
-        CallsiteParameter.PROCESS_NAME: (
-            lambda module, frame_info: get_processname()
-        ),
+        CallsiteParameter.PATHNAME: _get_callsite_pathname,
+        CallsiteParameter.FILENAME: _get_callsite_filename,
+        CallsiteParameter.MODULE: _get_callsite_module,
+        CallsiteParameter.FUNC_NAME: _get_callsite_func_name,
+        CallsiteParameter.LINENO: _get_callsite_lineno,
+        CallsiteParameter.THREAD: _get_callsite_thread,
+        CallsiteParameter.THREAD_NAME: _get_callsite_thread_name,
+        CallsiteParameter.PROCESS: _get_callsite_process,
+        CallsiteParameter.PROCESS_NAME: _get_callsite_process_name,
     }
     _record_attribute_map: ClassVar[dict[CallsiteParameter, str]] = {
         CallsiteParameter.PATHNAME: "pathname",
@@ -741,11 +846,7 @@ class CallsiteParameterAdder:
         event_dict_key: str
         record_attribute: str
 
-    __slots__ = [
-        "_active_handlers",
-        "_additional_ignores",
-        "_record_mappings",
-    ]
+    __slots__ = ("_active_handlers", "_additional_ignores", "_record_mappings")
 
     def __init__(
         self,
@@ -759,7 +860,7 @@ class CallsiteParameterAdder:
         # module should not be logging using structlog.
         self._additional_ignores = ["logging", *additional_ignores]
         self._active_handlers: list[
-            tuple[CallsiteParameter, Callable[[str, inspect.Traceback], Any]]
+            tuple[CallsiteParameter, Callable[[str, FrameType], Any]]
         ] = []
         self._record_mappings: list[CallsiteParameterAdder._RecordMapping] = []
         for parameter in parameters:
@@ -789,9 +890,8 @@ class CallsiteParameterAdder:
             frame, module = _find_first_app_frame_and_name(
                 additional_ignores=self._additional_ignores
             )
-            frame_info = inspect.getframeinfo(frame)
             for parameter, handler in self._active_handlers:
-                event_dict[parameter.value] = handler(module, frame_info)
+                event_dict[parameter.value] = handler(module, frame)
         return event_dict
 
 
@@ -808,12 +908,14 @@ class EventRenamer:
        some processors may rely on the presence and meaning of the ``event``
        key.
 
-    :param to: Rename ``event_dict["event"]`` to ``event_dict[to]``
-    :param replace_by: Rename ``event_dict[replace_by]`` to
-        ``event_dict["event"]``. *replace_by* missing from ``event_dict`` is
-        handled gracefully.
+    Args:
+        to: Rename ``event_dict["event"]`` to ``event_dict[to]``
 
-    .. versionadded:: 22.1
+        replace_by:
+            Rename ``event_dict[replace_by]`` to ``event_dict["event"]``.
+            *replace_by* missing from ``event_dict`` is handled gracefully.
+
+    .. versionadded:: 22.1.0
 
     See also the :ref:`rename-event` recipe.
     """
